﻿// Ionic Starter App

// angular.module is a global place for creating, registering and retrieving Angular modules
// 'starter' is the name of this angular module example (also set in a <body> attribute in index.html)
// the 2nd parameter is an array of 'requires'
// 'starter.services' is found in services.js
// 'starter.controllers' is found in controllers.js
angular.module('starter', ['ionic', 'starter.controllers', 'starter.services', 'starter.directives'])

.run(function ($ionicPlatform, $rootScope, $state, $location, $timeout, $ionicHistory, $ionicViewSwitcher) {
    $ionicPlatform.ready(function () {
        // Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
        // for form inputs)
        if (cordova.platformId === 'ios' && window.cordova && window.cordova.plugins && window.cordova.plugins.Keyboard) {
            cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
            cordova.plugins.Keyboard.disableScroll(true);
        }
        if (window.StatusBar) {
            // org.apache.cordova.statusbar required
            StatusBar.styleDefault();
        }
        //初始化极光推送
        window.plugins.jPushPlugin.init();
        //window.plugins.jPushPlugin.setDebugMode(true);
    });
    //设置双击退出
    $ionicPlatform.registerBackButtonAction(function (e) {
        //判断处于哪个页面时双击退出
        if ($location.path() == '/tab/home' || $location.path() == '/tab/deal' || $location.path() == '/tab/find' || $location.path() == '/tab/mine' || $location.path() == '/login') {
            if ($rootScope.backButtonPressedOnceToExit) {
                ionic.Platform.exitApp();
            }
            else {
                $rootScope.backButtonPressedOnceToExit = true;
                window.plugins.toast.showShortTop('再按一次退出系统');
                setTimeout(function () {
                    $rootScope.backButtonPressedOnceToExit = false;
                }, 2000);
            }
        }
        else {
            $ionicViewSwitcher.nextDirection("back");
            if ($ionicHistory.backView()) {
                $ionicHistory.goBack();
            } else {
                $state.go('tab.home');
            }
        }
        e.preventDefault();
        return false;
    }, 101);
})

.config(function ($stateProvider, $urlRouterProvider, $ionicConfigProvider) {
    $ionicConfigProvider.views.maxCache(30);
    $ionicConfigProvider.views.forwardCache(10)
    $ionicConfigProvider.platform.ios.tabs.style('standard');
    $ionicConfigProvider.platform.ios.tabs.position('bottom');
    $ionicConfigProvider.platform.android.tabs.style('standard');
    $ionicConfigProvider.platform.android.tabs.position('bottom');
    $ionicConfigProvider.platform.ios.navBar.alignTitle('center');
    $ionicConfigProvider.platform.android.navBar.alignTitle('center');
    $ionicConfigProvider.platform.ios.backButton.previousTitleText('').icon('ion-ios-arrow-thin-left');
    $ionicConfigProvider.platform.android.backButton.previousTitleText('').icon('ion-android-arrow-back');
    $ionicConfigProvider.platform.ios.views.transition('ios');
    $ionicConfigProvider.platform.android.views.transition('android');
    $stateProvider
    .state('tab', {
        url: '/tab',
        abstract: true,
        templateUrl: 'templates/tabs.html'
    })
    .state('tab.home', {
        url: '/home',
        views: {
            'tab-home': {
                templateUrl: 'templates/home.html',
                controller: 'homeControl'
            }
        }
    })
    .state('tab.deal', {
        cache: false,
        url: '/deal',
        params: { 'tradingNo': '0' },
        views: {
            'tab-deal': {
                templateUrl: 'templates/deal.html',
                controller: 'dealControl'
            }
        }
    })
    .state('tab.find', {
        cache: false,
        url: '/find',
        views: {
            'tab-find': {
                templateUrl: 'templates/find.html',
                controller: 'findControl'
            }
        }
    })
    .state('tab.mine', {
        url: '/mine',
        views: {
            'tab-mine': {
                templateUrl: 'templates/mine.html',
                controller: 'mineControl'
            }
        }
    })
    .state('login', {
        cache: false,
        url: '/login',
        templateUrl: 'templates/login.html',
        controller: 'loginControl'
    })
    .state('logout', {
        cache: false,
        url: '/logout',
        templateUrl: 'templates/logout.html',
        controller: 'logoutControl'
    })
    .state('register', {
        cache: true,
        url: '/register',
        templateUrl: 'templates/register.html',
        controller: 'registerControl'
    })
    .state('retrievePassword', {
        cache: true,
        url: '/retrievePassword',
        templateUrl: 'templates/retrievePassword.html',
        controller: 'retrievePasswordControl'
    })
    .state('recharge', {
        cache: false,
        url: '/recharge',
        templateUrl: 'templates/recharge.html',
        controller: 'rechargeControl'
    })
    .state('scoreExchange', {
        cache: false,
        url: '/scoreExchange',
        templateUrl: 'templates/scoreExchange.html',
        controller: 'scoreExchangeControl'
    })
    .state('settings', {
        cache: true,
        url: '/settings',
        templateUrl: 'templates/settings.html',
        controller: 'settingsControl'
    })
    .state('myMessage', {
        cache: true,
        url: '/myMessage',
        templateUrl: 'templates/myMessage.html',
        controller: 'myMessageControl'
    })
    .state('myDraw', {
        cache: false,
        url: '/myDraw',
        templateUrl: 'templates/myDraw.html',
        controller: 'myDrawControl'
    })
    .state('myDrawExchanged', {
        cache: false,
        url: '/myDrawExchanged',
        templateUrl: 'templates/myDrawExchanged.html',
        controller: 'myDrawExchangedControl'
    })
    .state('myDrawTimeover', {
        cache: false,
        url: '/myDrawTimeover',
        templateUrl: 'templates/myDrawTimeover.html',
        controller: 'myDrawTimeoverControl'
    })
    .state('myDeal', {
        cache: false,
        url: '/myDeal',
        templateUrl: 'templates/myDeal.html',
        controller: 'myDealControl'
    })
    .state('myRecharge', {
        cache: false,
        url: '/myRecharge',
        templateUrl: 'templates/myRecharge.html',
        controller: 'myRechargeControl'
    })
    .state('myPersonInfo', {
        cache: false,
        url: '/myPersonInfo',
        templateUrl: 'templates/myPersonInfo.html',
        controller: 'myPersonInfoControl'
    })
    .state('myHeadImage', {
        cache: false,
        url: '/myHeadImage',
        templateUrl: 'templates/myHeadImage.html',
        controller: 'myHeadImageControl'
    })
    .state('myWechatShare', {
        cache: false,
        url: '/myWechatShare',
        templateUrl: 'templates/myWechatShare.html',
        controller: 'myWechatShareControl'
    })
    .state('mySuggest', {
        cache: false,
        url: '/mySuggest',
        templateUrl: 'templates/mySuggest.html',
        controller: 'mySuggestControl'
    })
    .state('myRecommend', {
        cache: false,
        url: '/myRecommend',
        templateUrl: 'templates/myRecommend.html',
        controller: 'myRecommendControl'
    })
    .state('myCustomerService', {
        cache: false,
        url: '/myCustomerService',
        templateUrl: 'templates/myCustomerService.html',
        controller: 'myCustomerServiceControl'
    })
    .state('boxDraw', {
        cache: true,
        url: '/boxDraw',
        templateUrl: 'templates/boxDraw.html',
        controller: 'boxDrawControl'
    })
    .state('selectPosition', {
        url: '/selectPosition',
        templateUrl: 'templates/selectPosition.html',
        controller: 'selectPositionControl'
    })
    .state('storeSearch', {
        url: '/storeSearch',
        templateUrl: 'templates/storeSearch.html',
        controller: 'storeSearchControl'
    })
    .state('store-classify', {
        url: '/storeClassify/:classifyId',
        cache: false,
        templateUrl: 'templates/storeClassify.html',
        controller: 'storeClassifyControl'
    })
    .state('store-detail', {
        url: '/storeDetail/:storeId',
        templateUrl: 'templates/storeDetail.html',
        controller: 'storeDetailControl'
    });

    $urlRouterProvider.otherwise('/tab/home');

});
